"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.endsWith = void 0;
const core_1 = require("@serenity-js/core");
/**
 * Creates an {@apilink Expectation|expectation} that is met when the actual `string` value
 * ends with the resolved value of `expected`.
 *
 * ## Ensuring that a given string ends with an expected substring
 *
 * ```ts
 * import { actorCalled } from '@serenity-js/core'
 * import { Ensure, endsWith } from '@serenity-js/assertions'
 *
 * await actorCalled('Ester').attemptsTo(
 *   Ensure.that('Hello World!', endsWith('!')),
 * )
 * ```
 *
 * @param expected
 *
 * @group Expectations
 */
function endsWith(expected) {
    return core_1.Expectation.thatActualShould('end with', expected)
        .soThat((actualValue, expectedValue) => actualValue.endsWith(expectedValue));
}
exports.endsWith = endsWith;
//# sourceMappingURL=endsWith.js.map