"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.includes = void 0;
const core_1 = require("@serenity-js/core");
/**
 * Creates an {@apilink Expectation|expectation} that is met when the actual `string` value
 * includes a substring of `expected`.
 *
 * ## Ensuring that a given string includes the expected substring
 *
 * ```ts
 * import { actorCalled } from '@serenity-js/core'
 * import { Ensure, includes } from '@serenity-js/assertions'
 *
 * await actorCalled('Ester').attemptsTo(
 *   Ensure.that('Hello World!', includes('World')),
 * )
 * ```
 *
 * @param expected
 *
 * @group Expectations
 */
function includes(expected) {
    return core_1.Expectation.thatActualShould('include', expected)
        .soThat((actualValue, expectedValue) => actualValue.includes(expectedValue));
}
exports.includes = includes;
//# sourceMappingURL=includes.js.map