"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.startsWith = void 0;
const core_1 = require("@serenity-js/core");
/**
 * Creates an {@apilink Expectation|expectation} that is met when the actual `string` value
 * starts with the resolved value of `expected`.
 *
 * ## Ensuring that a given string starts with an expected substring
 *
 * ```ts
 * import { actorCalled } from '@serenity-js/core'
 * import { Ensure, startsWith } from '@serenity-js/assertions'
 *
 * await actorCalled('Ester').attemptsTo(
 *   Ensure.that('Hello World!', startsWith('Hello')),
 * )
 * ```
 *
 * @param expected
 *
 * @group Expectations
 */
function startsWith(expected) {
    return core_1.Expectation.thatActualShould('start with', expected)
        .soThat((actualValue, expectedValue) => actualValue.startsWith(expectedValue));
}
exports.startsWith = startsWith;
//# sourceMappingURL=startsWith.js.map